ApiException class

API/Network related exceptions

Inheritance

Constructors

ApiException({required String message, String? code, dynamic originalError})
ApiException.from(dynamic error)
factory

Properties

backendMessage String
Smart error message extractor. Dynamically captures the backend message (whether it is a String or a JSON Map) at runtime without creating dependencies on underlying HTTP libraries (like Dio).
no setter
code String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
originalError → dynamic
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited