AuthException class

Authentication related exceptions

Inheritance

Constructors

AuthException({required String message, String? code, dynamic originalError})
AuthException.invalidCredentials()
factory
AuthException.tokenExpired()
factory
AuthException.unauthorized()
factory

Properties

code String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
originalError → dynamic
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited