ApiClient class

Dio-based API Client with token management and error handling

Constructors

ApiClient(SecureStorageService _secureStorage, {required String baseUrl})

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete<T>(String path, {Map<String, dynamic>? queryParameters}) Future<T>
DELETE request
get<T>(String path, {Map<String, dynamic>? queryParameters}) Future<T>
GET request
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post<T>(String path, {dynamic data, Map<String, dynamic>? queryParameters}) Future<T>
POST request
put<T>(String path, {dynamic data, Map<String, dynamic>? queryParameters}) Future<T>
PUT request
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited