ApiResponse<T> class

Generic API response wrapper

Constructors

ApiResponse({required bool success, T? data, String? message, String? code})
ApiResponse.fromJson(Map<String, dynamic> json, T fromJsonT(dynamic)?)
factory

Properties

code String?
final
data → T?
final
hashCode int
The hash code for this object.
no setterinherited
isFailure bool
no setter
isSuccess bool
no setter
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited