SecureStorageService class
Secure storage service for tokens and sensitive data
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> - Clear all data (logout)
-
contains(
String key) → Future< bool> - Check if data exists
-
delete(
String key) → Future< void> - Delete specific key
-
getRefreshToken(
) → Future< String?> - Retrieve refresh token
-
getToken(
) → Future< String?> - Retrieve token
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveRefreshToken(
String token) → Future< void> - Save refresh token
-
saveToken(
String token) → Future< void> - Save token to secure storage
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited